==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/CRLNumber.h <==
// public class gnu.java.security.x509.ext.CRLNumber

// class file dependencies
// @dep_class b7bbf58e3ad5bb2e gnu_java_security_x509_ext_CRLNumber
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_CRLNumber_H_
#define _JC_gnu_java_security_x509_ext_CRLNumber_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs	_jc_gnu_java_security_x509_ext_CRLNumber$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs	_jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$refs	_jc_gnu_java_security_x509_ext_CRLNumber$refs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$nonrefs	_jc_gnu_java_security_x509_ext_CRLNumber$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$object	_jc_gnu_java_security_x509_ext_CRLNumber$object;

typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct	_jc_gnu_java_security_x509_ext_CRLNumber$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vmethods	_jc_gnu_java_security_x509_ext_CRLNumber$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vtable	_jc_gnu_java_security_x509_ext_CRLNumber$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vtype	_jc_gnu_java_security_x509_ext_CRLNumber$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24CRLNumber;
};
extern _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct _jc_gnu_java_security_x509_ext_CRLNumber$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_init$e813f5730a068697(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *, struct _jc_java_math_BigInteger$object *);
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_CRLNumber$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$getNumber$20f2db7703bbea85(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$getNumber$20f2db7703bbea85;
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);
	struct _jc_java_math_BigInteger$object	*(*getNumber$20f2db7703bbea85)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_CRLNumber$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_CRLNumber$vmethods	gnu_java_security_x509_ext_CRLNumber;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_CRLNumber$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_CRLNumber$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs {
	struct _jc_java_math_BigInteger$object	*number;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CRLNumber$refs {
    _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs	gnu_java_security_x509_ext_CRLNumber;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CRLNumber$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs	gnu_java_security_x509_ext_CRLNumber;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$object {
	_jc_gnu_java_security_x509_ext_CRLNumber$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_CRLNumber$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_CRLNumber$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_CRLNumber$vtype _jc_gnu_java_security_x509_ext_CRLNumber$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_CRLNumber, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_CRLNumber$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_CRLNumber_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/CRLNumber.h <==
// public class gnu.java.security.x509.ext.CRLNumber

// class file dependencies
// @dep_class b7bbf58e3ad5bb2e gnu_java_security_x509_ext_CRLNumber
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_CRLNumber_H_
#define _JC_gnu_java_security_x509_ext_CRLNumber_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs	_jc_gnu_java_security_x509_ext_CRLNumber$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs	_jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$refs	_jc_gnu_java_security_x509_ext_CRLNumber$refs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$nonrefs	_jc_gnu_java_security_x509_ext_CRLNumber$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$object	_jc_gnu_java_security_x509_ext_CRLNumber$object;

typedef struct _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct	_jc_gnu_java_security_x509_ext_CRLNumber$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vmethods	_jc_gnu_java_security_x509_ext_CRLNumber$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vtable	_jc_gnu_java_security_x509_ext_CRLNumber$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_CRLNumber$vtype	_jc_gnu_java_security_x509_ext_CRLNumber$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24CRLNumber;
};
extern _jc_gnu_java_security_x509_ext_CRLNumber$fields_struct _jc_gnu_java_security_x509_ext_CRLNumber$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_init$e813f5730a068697(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_CRLNumber$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$getNumber$20f2db7703bbea85(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$getNumber$20f2db7703bbea85;
extern _jc_method _jc_gnu_java_security_x509_ext_CRLNumber$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_CRLNumber$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_CRLNumber$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getNumber$20f2db7703bbea85)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_CRLNumber$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_CRLNumber$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_CRLNumber$vmethods	gnu_java_security_x509_ext_CRLNumber;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_CRLNumber$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_CRLNumber$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs {
	struct _jc_java_math_BigInteger$object	*number;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CRLNumber$refs {
    _jc_gnu_java_security_x509_ext_CRLNumber$sub_refs	gnu_java_security_x509_ext_CRLNumber;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_CRLNumber$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_CRLNumber$sub_nonrefs	gnu_java_security_x509_ext_CRLNumber;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_CRLNumber$object {
	_jc_gnu_java_security_x509_ext_CRLNumber$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_CRLNumber$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_CRLNumber$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_CRLNumber$vtype _jc_gnu_java_security_x509_ext_CRLNumber$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_CRLNumber, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_CRLNumber$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_CRLNumber_H_ */
